\name{GDTI.mc}
\alias{GDTI.mc}
\title{
Monte Carlo Generalized Disequilibrium Test for Association in Qualitative Traits Incorporating Imprinting Effects
}
\description{
This function calculates the score function and the elements of the Fisher??s information matrix for a pedigree with missing genotypes by the Monte Carlo sampling and scheme.
}
\usage{
GDTI.mc(ped)
}
\arguments{
  \item{ped}{
The name of a standard linkage pedigree file or a matrix/dataframe containing pedigree relationship, genotype, and phenotype information, one row for each individual. The first 5 columns give the pedigree id, individual id, father id (0 if founder), mother id (0 if founder), and sex (1=male, 2=female, 0 = unknown), in that order. Note that these fields need to be numeric. The 6th column gives the affection status (1=unaffected, 2=affected, 9=unknown). The remaining columns code for marker genotypes (2 columns per SNP), with the two alleles for each marker represented by two consecutive numbers (0=missing). 
}
}
\details{
Datasets with missing genotypes are allowed, since the slink procedure can recapture missing information given the observed genotypes.
}
\value{
The function outputs the values of the score function and the Fisher??s information matrix for each pedigree.
}
\references{
Chen, W. M., Manichaikul, A., Rich, S. S. (2009). A generalized family-based association test for dichotomous traits. The American Journal of Human Genetics, 85(3):364-376.

Ott, J., Lathrop, G. M. (1990). SLINK: a general simulation program for linkage analysis. The American Journal of Human Genetics, 47:A204.

Li, J. L., Wang, P., Fung, W. K., Zhou, J. Y. (2017). Generalized disequilibrium test for association in qualitative traits incorporating imprinting effects based on extended pedigrees. (submitted)
}
\author{
Jian-Long Li, Peng Wang, Wing Kam Fung, Ji-Yuan Zhou.
}
\note{
The function does not output the value of the test statistic and the corresponding P value directly, and it only outputs the score function and the elements of Fisher??s information matrix for each pedigree.
}
\seealso{
\link{MCGDTI}, \link{GDT_ME}, \link{GDTI}, \link{MCGDT_ME}, \link{MC_GDTI}, \link{slink}, \link{makeped}.
}
\examples{

}

