\name{MCGDTI}
\alias{MCGDTI}
\title{
Monte Carlo Generalized Disequilibrium Test for Association in Qualitative Traits Incorporating Imprinting Effects Based on Extended Pedigrees
}
\description{
Monte Carlo generalized disequilibrium test for association in qualitative traits incorporating imprinting effects based on extended pedigrees.
}
\usage{
MCGDTI(ped, mcsize, header = T, loci = NULL, status_missing = 9, af = NULL)
}
\arguments{
  \item{ped}{
The name of a standard linkage pedigree file or a matrix/dataframe containing pedigree relationship, genotype, and phenotype information, one row for each individual. The first 5 columns give the pedigree id, individual id, father id (0 if founder), mother id (0 if founder), and sex (1=male, 2=female, 0 = unknown), in that order. Note that these fields need to be numeric. The 6th column gives the affection status (1=unaffected, 2=affected, 9=unknown). The remaining columns code for marker genotypes (2 columns per SNP), with the two alleles for each marker represented by two consecutive numbers (0=missing).
}
  \item{mcsize}{
The Monte Carlo sample size. It can take any positive integer.
}
  \item{header}{
The header of input data. If ped contains variable names, header is taken as TRUE (or T); otherwise, header is taken as FALSE (or F). The default value is FALSE (or F).
}
  \item{loci}{
The name of a standard linkage loci file.
}
  \item{status_missing}{
The input variable "status_missing" is the missing value for the affection status in the data file, and the default value is 9. It can take NA, but cannot take 1, 2, or any other string values.
}
  \item{af}{
Dataframe/matrix of marker allele frequencies, one column for each marker locus. If af=NULL, then it will be estimated from typed founders.
}
 }
\details{
For complete pedigree data (without missing genotypes), the generalized disequilibrium test incorporating imprinting effects (GDTI) and the generalized disequilibrium test with the moment estimate of the variance (GDT-ME) for association between qualitative traits and alleles at SNP markers, and the pedigree parental-asymmetry test (PPAT) for imprinting effects. For incomplete pedigree data (with missing genotypes), the code contains the Monte Carlo generalized disequilibrium test incorporating imprinting effects (MCGDTI) and the Monte Carlo generalized disequilibrium test with the moment estimate of the variance (MCGDT-ME) for association between qualitative traits and alleles at SNP markers, and the Monte Carlo pedigree parental-asymmetry test (MCPPAT) for imprinting effects. Data sets with missing genotypes are allowed, since the slink procedure can recapture missing information given the observed genotypes.
}
\value{
The function outputs the values of all the test statistics (Tstat: GDTI, GDT-ME and PPAT for complete pedigree data and MCGDTI, MCGDT-ME and MCPPAT for incomplete pedigree data) and the corresponding P values (pvalue).
}
\references{
Chen, W. M., Manichaikul, A., Rich, S. S. (2009). A generalized family-based association test for dichotomous traits. The American Journal of Human Genetics, 85(3):364-376.

Ding, J., Lin, S., Liu, Y. (2006). Monte Carlo pedigree disequilibrium test for markers on the X chromosome. The American Journal of Human Genetics, 79(3):567-573.

Ott, J., Lathrop, G. M. (1990). SLINK: a general simulation program for linkage analysis. The American Journal of Human Genetics, 47:A204.

Li, J. L., Wang, P., Fung, W. K., Zhou, J. Y. (2017). Generalized disequilibrium test for association in qualitative traits incorporating imprinting effects based on extended pedigrees. (submitted)

Zhou, J. Y., Ding, J., Fung, W. K., Lin, S. (2010). Detection of parent-of-origin effects using general pedigree data. Genetic Epidemiology, 34(2):151-158.
}
\author{
Jian-Long Li, Peng Wang, Wing Kam Fung, Ji-Yuan Zhou.
}
\note{
ped is required. The results may be a little different for different runs when the pedigrees are incomplete due to the Monte Carlo sampling and estimation scheme.
}

\seealso{
\link{ped}, \link{GDT_ME}, \link{GDTI}, \link{GDTI.mc}, \link{MCGDT_ME}, \link{MC_GDTI}, \link{slink}, \link{makeped}, \link{pedig}.
}

