\name{MC_GDT}
\alias{MC_GDT}
\title{
A Generalized Family-Based Association Test for Dicotomous Traits by using Monte Carlo sampling and scheme
}
\description{
Based on the general pedigree data from makeped and slink procedures, the function calculates the numerators and denominator of MCGDT for each pedigree sample.
}
\usage{
MC_GDT(ped1, mcsize)
}
\arguments{
  \item{ped1}{
The name of a standard linkage pedigree file or a matrix/dataframe containing pedigree relationship, genotype, and phenotype information, one row for each individual. The first 5 columns give the pedigree id, individual id, father id (0 if founder), mother id (0 if founder), and sex (1=male, 2=female), in that order. Note that these fields need to be numeric. The sixth column gives the affection status (1=unaffected; 2=affected; 0=unknown). The remaining columns code for marker genotypes (2 columns per SNP), with the two alleles for each marker represented by two consecutive numbers (0=missing).
}
  \item{mcsize}{
The Monte Carlo sample size. It can take any positive integer.
}
}
\details{
After being processed by makeped and slink procedures, the input data set is transformed into complete pedigree data. Based on the data, the function calculates the numerators and denominator of MCGDTI statistic for all pedigrees.
}
\value{
The function returns the numerators and denominator of MCGDT for all pedigrees.
}
\references{
Li JL, Wang P, Wing KF, Zhou JY 2016 Generalized Disequilibrium Test for Association in Qualitative Traits Incorporating Imprinting Effects Based on Extended Pedigrees. (submitted)

Chen, W. M., Manichaikul, A., Rich, S. S. (2009). A generalized family-based association test for dichotomous traits. The American Journal of Human Genetics, 85(3):364-376.

Ding, J., Lin, S., Liu, Y. (2006). Monte Carlo pedigree disequilibrium test for markers
on the X chromosome. The American Journal of Human Genetics, 79(3):567-573.
}
\author{
Jian-Long Li, Peng Wang, Wing Kam FUng, Ji-Yuan Zhou.
}
\note{
The function does not output statistic and P value directly, and it only returns the numerators and denominator of MCGDT.
}
\seealso{
\link{MCGDTI}, \link{GDT}, \link{GDTI.mc}, \link{GDTI}, \link{MC_GDTI},\link{slink}, \link{makeped}.
}
\examples{
}
